# Copyright 2013-2024 Lawrence Livermore National Security, LLC and other
# Spack Project Developers. See the top-level COPYRIGHT file for details.
#
# SPDX-License-Identifier: (Apache-2.0 OR MIT)

from spack.package import *

class PyNeuralactivitycubic(PythonPackage):
    """Computation of local and signal-close-to-noise calcium activity."""

    homepage = "https://github.com/Indoc-Research/NeuralActivityCubic"
    pypi = "neuralactivitycubic/neuralactivitycubic-0.0.3.tar.gz"

    maintainers("DennisDoll", "mloshakov", "acascais")

    version("0.0.3", sha256="516e99e44a70d83f526a128e653a63c6b7ae4ffbe362fe7854121999a7c8fecb")

    depends_on("python@3.10:", type=("build", "run"))
    depends_on("py-ipywidgets@8.0.4:8", type=("build", "run"))
    depends_on("py-ipyfilechooser@0.6.0", type=("build", "run"))
    depends_on("py-imageio@2.31:2", type=("build", "run"))
    depends_on("py-imageio-ffmpeg@0.4:0.5", type=("build", "run"))
    depends_on("py-matplotlib@3.8:3.9", type=("build", "run"))
    depends_on("py-scipy@1.11.4:", type=("build", "run"))
    depends_on("py-numpy@1.26.0:", type=("build", "run"))
    depends_on("py-pandas@2.2.1:2.3", type=("build", "run"))
    depends_on("py-pybaselines@1.1.0:", type=("build", "run"))
    depends_on("py-roifile@2024.1.10:", type=("build", "run"))
    depends_on("py-shapely@2.0.1:", type=("build", "run"))
    depends_on("py-scikit-image@0.22.0:", type=("build", "run"))

    depends_on("py-jupyterlab@4.3.3:", type=("run"))

    depends_on("py-setuptools", type="build")


    @run_after('install')
    @on_package_attributes(run_tests=True)
    def install_test(self):
        with working_dir('spack-test', create=True):
            python('-c','import neuralactivitycubic')
